#!/usr/bin/perl -w

use POSIX;
use strict;
use Getopt::Long;
use vars qw($opt_V $opt_h $opt_t $opt_f $PROGNAME $returncode $i);
use lib "/usr/lib/nagios/plugins";
use utils qw(%ERRORS &print_revision &support &usage);

$PROGNAME = "check_mounts";
my @failedpaths;

Getopt::Long::Configure('bundling');
GetOptions
    ("V"   => \$opt_V, "version"    => \$opt_V,
     "h"   => \$opt_h, "help"       => \$opt_h,
     "t=i" => \$opt_t, "timeout=i"  => \$opt_t,
     "f=i" => \$opt_f, "files=i"    => \$opt_f);

if ($opt_V) {
    &print_revision($PROGNAME,'$Revision: 0.1 $');
    exit $ERRORS{'OK'};
}

if ($opt_h) {
    &print_help(); 
    exit $ERRORS{'OK'};
}

unless (defined $opt_t) {
    $opt_t = $utils::TIMEOUT ;  # default timeout
}

unless (defined $opt_f) {
    $opt_f = 2; # default number of files to fail with.
}

# Just in case of problems, let's not hang Nagios
$SIG{'ALRM'} = sub {
        print "Timeout: The plugin could not complete.\n";
        exit $ERRORS{'UNKNOWN'};
};
alarm($opt_t);

sub check_files {
    my @mounts = @_;
    $i=0;
    while (@_) {
        my $path = shift;
        chomp $path;
        my @files = `ls --color=none $path`;
        chomp for @files;
        if ( (scalar @files) > $opt_f ) {
            #print "The mount $path is okay.\n";
            $i++
        } else {
            #print "The mount $path is not okay.\n";
            push(@failedpaths, $path);
            }
        }
    unless ($i == scalar @mounts) {
        if (@failedpaths) {
	    foreach my $line (@failedpaths) {
		print "Critical: mount $line failed; ";
		}
    	}
	exit $ERRORS{'CRITICAL'};
    } else {
	print "OK: Mounts are fine.\n";
        exit $ERRORS{'OK'};
    }
    
}
    
open(COMMAND, '-|', 'awk -F " " \'/:/ && ! /#/ {print $2}\' /etc/fstab');
    my @response;
    while (<COMMAND>) { 
        push(@response, $_); 
    }

sub print_help () {
    &print_revision($PROGNAME,'$Revision: 0.1 $');
    print "Copyright (c) 2005 Nathan Oyler

This plugin verifies that all nfs mounts in /etc/fstab are mounted and working.

";
    &print_usage();
    &support();
}

sub print_usage () {
    print "Usage: $PROGNAME (-t, --timeout) (-f, --num of files to check)\n";
    print "Usage: $PROGNAME --help\n";
    print "Usage: $PROGNAME --version\n";
}
&check_files(@response);


#$returncode = &check_files(@response);
#print $returncode;
